==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/ContextualMenu/ContextualMenu.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, css } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.array.map.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { DirectionalHint } from '../../common/DirectionalHint.js';
import { Callout } from '../Callout/Callout.js';
import { ContextualMenuItem } from './ContextualMenuItem.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction({
  disableCaching: true
});

var ContextualMenuBase = function (_BaseComponent) {
  _inherits(ContextualMenuBase, _BaseComponent);

  var _super = _createSuper(ContextualMenuBase);

  function ContextualMenuBase() {
    _classCallCheck(this, ContextualMenuBase);

    return _super.apply(this, arguments);
  }

  _createClass(ContextualMenuBase, [{
    key: "created",
    value: function created() {
      console.log(this.target);
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var target = this.target,
          directionalHint = this.directionalHint,
          calloutProps = this.calloutProps,
          onDismiss = this.onDismiss,
          contextMenuStyle = this.contextMenuStyle,
          classNames = this.classNames,
          items = this.items;
      return h(Callout, {
        "attrs": {
          "target": target,
          "directional-hint": directionalHint,
          "is-beak-visible": false
        },
        "class": css('ms-ContextualMenu-Callout', calloutProps && calloutProps.className),
        "on": {
          "dismiss": onDismiss
        }
      }, [h("div", {
        "style": contextMenuStyle,
        "class": classNames.container
      }, [h("div", {
        "class": classNames.root
      }, [h("ul", {
        "class": classNames.list,
        "attrs": {
          "role": "menu"
        }
      }, [items.map(function (item, index) {
        return h("li", {
          "key": item.key || index,
          "class": classNames.item
        }, [h(ContextualMenuItem, {
          "attrs": {
            "item": item,
            "prop-class-names": classNames
          }
        })]);
      })])])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          className = this.className;
      return getClassNames(styles, {
        theme: theme,
        className: className
      });
    }
  }, {
    key: "contextMenuStyle",
    get: function get() {
      var targetBoundingRect = this.target.getBoundingClientRect();
      var targetWidth = targetBoundingRect.width - 2;
      return {
        width: "".concat(targetWidth, "px")
      };
    }
  }]);

  return ContextualMenuBase;
}(BaseComponent);

__decorate([Prop(), __metadata("design:type", HTMLElement)], ContextualMenuBase.prototype, "target", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], ContextualMenuBase.prototype, "calloutProps", void 0);

__decorate([Prop({
  type: Number,
  "default": DirectionalHint.bottomAutoEdge
}), __metadata("design:type", Boolean)], ContextualMenuBase.prototype, "directionalHint", void 0);

__decorate([Prop({
  type: Function,
  "default": function _default() {
    return null;
  }
}), __metadata("design:type", Function)], ContextualMenuBase.prototype, "onDismiss", void 0);

__decorate([Prop({
  type: Array,
  "default": function _default() {
    return [];
  }
}), __metadata("design:type", Array)], ContextualMenuBase.prototype, "items", void 0);

ContextualMenuBase = __decorate([Component({
  components: {
    Callout: Callout,
    ContextualMenuItem: ContextualMenuItem
  }
})], ContextualMenuBase);

export { ContextualMenuBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/ContextualMenu/ContextualMenu.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, css } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.array.map';
import 'core-js/modules/es.number.constructor';
import { DirectionalHint } from '../../common/DirectionalHint.js';
import { Callout } from '../Callout/Callout.js';
import { ContextualMenuItem } from './ContextualMenuItem.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction({
  disableCaching: true
});

var ContextualMenuBase = function (_BaseComponent) {
  _inherits(ContextualMenuBase, _BaseComponent);

  var _super = _createSuper(ContextualMenuBase);

  function ContextualMenuBase() {
    _classCallCheck(this, ContextualMenuBase);

    return _super.apply(this, arguments);
  }

  _createClass(ContextualMenuBase, [{
    key: "created",
    value: function created() {
      console.log(this.target);
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var target = this.target,
          directionalHint = this.directionalHint,
          calloutProps = this.calloutProps,
          onDismiss = this.onDismiss,
          contextMenuStyle = this.contextMenuStyle,
          classNames = this.classNames,
          items = this.items;
      return h(Callout, {
        "attrs": {
          "target": target,
          "directional-hint": directionalHint,
          "is-beak-visible": false
        },
        "class": css('ms-ContextualMenu-Callout', calloutProps && calloutProps.className),
        "on": {
          "dismiss": onDismiss
        }
      }, [h("div", {
        "style": contextMenuStyle,
        "class": classNames.container
      }, [h("div", {
        "class": classNames.root
      }, [h("ul", {
        "class": classNames.list,
        "attrs": {
          "role": "menu"
        }
      }, [items.map(function (item, index) {
        return h("li", {
          "key": item.key || index,
          "class": classNames.item
        }, [h(ContextualMenuItem, {
          "attrs": {
            "item": item,
            "prop-class-names": classNames
          }
        })]);
      })])])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var styles = this.styles,
          theme = this.theme,
          className = this.className;
      return getClassNames(styles, {
        theme: theme,
        className: className
      });
    }
  }, {
    key: "contextMenuStyle",
    get: function get() {
      var targetBoundingRect = this.target.getBoundingClientRect();
      var targetWidth = targetBoundingRect.width - 2;
      return {
        width: "".concat(targetWidth, "px")
      };
    }
  }]);

  return ContextualMenuBase;
}(BaseComponent);

__decorate([Prop(), __metadata("design:type", HTMLElement)], ContextualMenuBase.prototype, "target", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], ContextualMenuBase.prototype, "calloutProps", void 0);

__decorate([Prop({
  type: Number,
  default: DirectionalHint.bottomAutoEdge
}), __metadata("design:type", Boolean)], ContextualMenuBase.prototype, "directionalHint", void 0);

__decorate([Prop({
  type: Function,
  default: function _default() {
    return null;
  }
}), __metadata("design:type", Function)], ContextualMenuBase.prototype, "onDismiss", void 0);

__decorate([Prop({
  type: Array,
  default: function _default() {
    return [];
  }
}), __metadata("design:type", Array)], ContextualMenuBase.prototype, "items", void 0);

ContextualMenuBase = __decorate([Component({
  components: {
    Callout: Callout,
    ContextualMenuItem: ContextualMenuItem
  }
})], ContextualMenuBase);

export { ContextualMenuBase };
